"""
@author: luojunhui
"""
from quart import Blueprint, jsonify, request

from server.api import Response, Record, Minigram, GetOffVideos, OssRank

my_blueprint = Blueprint('LongArticlesMatchServer', __name__)


def Routes(mysql_client, config):
    """
    路由代码
    """

    @my_blueprint.route('/healthcheck')
    def healthcheck():
        """
        Hello World Test
        :return:
        """
        return jsonify({'message': 'Hello, World!'})

    @my_blueprint.route('/search_videos', methods=['POST'])
    async def search_videos_from_the_web():
        """
        record Data
        :return:
        """
        params = await request.get_json()
        record = Record(params=params, mysql_client=mysql_client, config=config)
        result = await record.deal()
        return jsonify(result)

    @my_blueprint.route('/recall_videos', methods=['POST'])
    async def recall_results():
        """
        获取视频分享卡片
        :return:
        """
        data = await request.get_json()
        response = Response(
            params=data,
            mysql_client=mysql_client,
            config=config
        )
        result = await response.deal()
        return jsonify(result)

    @my_blueprint.route("/choose_minigram", methods=['POST'])
    async def match_minigram():
        """
        获取小程序信息
        :return:
        """
        data = await request.get_json()
        mini_program = Minigram(params=data, config=config)
        result = await mini_program.deal()
        return jsonify(result)

    @my_blueprint.route("/get_off_videos", methods=['POST'])
    async def get_off_videos():
        """
        自动下架视频记录
        :return:
        """
        data = await request.get_json()
        get_off_video = GetOffVideos(params=data, mysql_client=mysql_client, config=config)
        result = await get_off_video.deal()
        return jsonify(result)
    
    @my_blueprint.route("/oss_rank", methods=['POST'])
    async def get_video_oss_rank():
        """
        获取content_id以及溯源id的oss路径信息并且通过 fission / read 排序
        """
        data = await request.get_json()
        oss_rank = OssRank(params=data, db_client=mysql_client)
        result = await oss_rank.deal()
        return jsonify(result)
    
    return my_blueprint
